<?php

// $Id: chuck.api.inc,v 1.1.2.1 2010/09/11 08:17:42 inadarei Exp $

/**
 * @file
 * Implementations of the various houseround kicks.
 */

interface i_chuck_hr_kick {
  function execute();
}


//----- LOGGING

/**
* Shortcut methods, to make logging just super-easy.
*/
function hrk_log   ($object, $label = '') {  _hrk_log($object, $label, 'log'); }
function hrk_warn  ($object, $label = '') {  _hrk_log($object, $label, 'warn'); }
function hrk_error ($object, $label = '') {  _hrk_log($object, $label, 'error'); }

function _hrk_log($object, $label = '', $severity = 'log') {
  static $logger;
  
  if (empty ($logger)) {
    $hrks = chuck_hrks_enabled();
    if (!empty($hrks['chuck_hrk_logging'])) {
      $logger = $hrks['chuck_hrk_logging'];
    }    
  }

  //-- If we were able to initialize at least one logger, try to log
  if (!empty($logger)) {  
    $logger->log($object, $label, $severity);
  }
}

class chuck_hrk_logging implements i_chuck_hr_kick {
  
  var $user_agent;
  var $logger_activated = FALSE;
  
  function __construct() {
    $agent_info_raw = $_SERVER['HTTP_USER_AGENT'];
    $this->user_agent = $this->parse_user_agent($agent_info_raw);
    $this->activate_logger();
  }
  
  function execute() {
  }

  /**
  * returns browser identifier key based on the raw user agent information.
  */
  function parse_user_agent($agent_info_raw) {
    if (strpos($agent_info_raw, 'Chrome/')) {
      return "chrome";
    }
    else if (strpos($agent_info_raw, 'Firefox/')) {
      return "firefox";
    }
    
    return 'unsupported browser';
  }
  
  function activate_logger() {
    if ($this->user_agent == "chrome")  {
        $lib_path = libraries_get_path('chromephp');
        if (file_exists($lib_path . '/ChromePhp.php')) {
          include_once($lib_path . '/ChromePhp.php');
          // Use file storage to avoid 4KB cookie problems.
          $file_dir_path = variable_get('file_directory_path', 'sites/default/path');
          ChromePhp::useFile(realpath($file_dir_path), '/' . $file_dir_path);
          $this->logger_activated = TRUE;
        }
    }
  }
  
  function log($object, $label = 'Chuck Logged:', $severity = 'log') {
    if ($this->user_agent == "chrome" && $this->logger_activated)  {
      if (!in_array($severity, array('log', 'warn', 'error'))) {
        $severity = 'log';
      }
      if (empty($label)) {
        ChromePhp::$severity($object);
      }
      else {
        ChromePhp::$severity($label, $object);
      }
    }
  }
}